@@ -1,5 +1,6 @@
 from Acquisition import aq_base
 from DateTime import DateTime
+from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.Five import BrowserView
 from ZODB.POSException import ConflictError
@@ -7,17 +8,21 @@ from ftw.publisher.core import states, communication
 from ftw.publisher.core.interfaces import IDataCollector
 from ftw.publisher.receiver import decoder
 from ftw.publisher.receiver import getLogger
+from ftw.publisher.receiver import helpers
 from ftw.publisher.receiver.events import AfterCreatedEvent, AfterUpdatedEvent
 from plone.app.uuid.utils import uuidToObject
 from zope import event
 from zope.component import getAdapters
-from zope.event import notify
-from zope.lifecycleevent import ObjectAddedEvent
+from zope.interface import alsoProvides
 from zope.publisher.interfaces import Retry
 import os.path
 import sys
 import traceback
-import plone.uuid
+
+try:
+    from plone.protect.interfaces import IDisableCSRFProtection
+except ImportError:
+    IDisableCSRFProtection = None
 
 
 class ReceiveObject(BrowserView):
@@ -32,6 +37,9 @@ class ReceiveObject(BrowserView):
         @return:    response string containing a representation  of a
         CommunicationState as string.
         """
+        if IDisableCSRFProtection:
+            alsoProvides(self.request, IDisableCSRFProtection)
+
         # get a logger instance
         self.logger = getLogger()
         try:
@@ -226,15 +234,7 @@ class ReceiveObject(BrowserView):
                 metadata['id'],
             ))
 
-            if hasattr(aq_base(object), '_setUID'):
-                object._setUID(metadata['UID'])
-
-            else:
-                setattr(object,
-                        plone.uuid.interfaces.ATTRIBUTE_NAME,
-                        metadata['UID'])
-
-                notify(ObjectAddedEvent(object))
+            helpers.set_uid(object, metadata['UID'])
 
             # object.processForm()
             new_object = True
@@ -288,13 +288,15 @@ class ReceiveObject(BrowserView):
             object.setModificationDate(modifiedDate)
             if not is_root:
                 catalog_tool.catalog_object(object,
-                                            '/'.join(object.getPhysicalPath()))
+                                            '/'.join(object.getPhysicalPath()),
+                                            idxs=['modified'])
 
         if parent_modified_date:
             parent = object.aq_inner.aq_parent
             parent.setModificationDate(parent_modified_date)
             catalog_tool.catalog_object(object,
-                                        '/'.join(object.getPhysicalPath()))
+                                        '/'.join(object.getPhysicalPath()),
+                                        idxs=['modified'])
 
         # return the appropriate CommunicationState - notify events
         if new_object:
@@ -491,9 +493,15 @@ class ReceiveObject(BrowserView):
         @type metadata:         dict
         @return:                None
         """
+
         positions = metadata['sibling_positions']
         parent = object.aq_inner.aq_parent
         object_ids = list(parent.objectIds())
+        obj_id = object.getId()
+
+        # Do nothing if the position is the same.
+        if positions[obj_id] == parent.getObjectPosition(obj_id):
+            return
 
         # move objects with no position info to the bottom
         for id in object_ids:
@@ -506,14 +514,6 @@ class ReceiveObject(BrowserView):
         # order objects
         parent.moveObjectsByDelta(object_ids, -len(object_ids))
 
-        # reindex all objects
-        for id in object_ids:
-            try:
-                parent.get(id).reindexObject(
-                    idxs=['positionInParent', 'getObjPositionInParent'])
-            except:
-                pass
-
 
 class TestConnection(BrowserView):
     """
@@ -533,3 +533,19 @@ class TestConnection(BrowserView):
             return 'ok'
         else:
             return 'Not a Plone-Site'
+
+
+class GetSavedData(BrowserView):
+
+    def __call__(self, *args, **kwargs):
+        download_format = self.request.get('download_format')
+        target_uid = self.request.get('uid')
+        cat = getToolByName(self.context, 'portal_catalog')
+        result = cat(UID=target_uid)
+        if len(result) != 1:
+            return ''
+        obj = result[0].getObject()
+        if download_format == 'csv':
+            return obj.download_csv(self.request, self.request.RESPONSE)
+        else:
+            return obj.download_tsv(self.request, self.request.RESPONSE)
