@@ -1,8 +1,12 @@
 from ftw.builder.testing import BUILDER_LAYER
+from ftw.testing import IS_PLONE_5
 from ftw.testing.layer import COMPONENT_REGISTRY_ISOLATION
+from plone.app.testing import applyProfile
 from plone.app.testing import IntegrationTesting
 from plone.app.testing import PloneSandboxLayer
+from plone.testing import z2
 from zope.configuration import xmlconfig
+import ftw.publisher.receiver.tests.builders
 
 
 class ReceiverLayer(PloneSandboxLayer):
@@ -17,6 +21,12 @@ class ReceiverLayer(PloneSandboxLayer):
             '</configure>',
             context=configurationContext)
 
+        z2.installProduct(app, 'Products.PloneFormGen')
+
+    def setUpPloneSite(self, portal):
+        applyProfile(portal, 'Products.PloneFormGen:default')
+        if IS_PLONE_5:
+            applyProfile(portal, 'plone.app.contenttypes:default')
 
 RECEIVER_FIXTURE = ReceiverLayer()
 RECEIVER_INTEGRATION = IntegrationTesting(
